import {
  select,
  selectAll,
  scaleOrdinal
} from 'd3';

// variables that define the structure of the svg are defined here
const svg = select('svg');
const width = +svg.attr('width'); 
const height = +svg.attr('height');
const centre_x = width / 2;
const centre_y = height / 2;

// setting of svg
svg.attr("preserveAspectRatio", "xMidYMid meet")
   .attr("viewBox", [0, 0, width * 2, height * 2]);

d3.json('https://gist.githubusercontent.com/AISWARYAMARAPATLA1999/93529e7ab031696659aeb4b7aeac5913/raw/181809b574b9857120a403d23b6227ab2de6348a/Friend%2520Network.json')
  .then(data => {

  // Not to overlap with each other and make away from each other.
  const simulation = d3.forceSimulation(data.nodes)
  	  // 'forceLink' pulls the nodes each other that are related.
      .force("link", d3.forceLink(data.links)
             .id(d => d.id)
             .distance(130))
  		// 'forceManyBody' generates repulsion between nodes.
      .force("charge", d3.forceManyBody()
             .strength(-500)
            )
  		// 'forceCollide' prevents the nodes collide each other
  		.force("collision", d3.forceCollide()
             	.radius(105)
            )
  		// 'forceCenter' make the nodes tie to the centre of the simulation
      .force("center", d3.forceCenter(width, height))
  ;

  // generating the links i.e., lines that connects the nodes.
  const link = svg.append("g")
  .selectAll("line")
    .data(data.links)
  	.join("line");
  
  // generating the nodes
  const node = svg.append("g")
    .attr("class", "node")
  	.selectAll("g")
    .data(data.nodes)
  	.enter()
  	.append("g")
    	.attr("transform", d => "translate(" + centre_x + ", " + centre_y + ")");
  
  // adding circle that rounds each node.
  node.append("circle")
  		.attr("r", 75)
  		.attr("fill", d => "GreenYellow");
  
  // adding the text to each of the node.
  node.append("text")
  			.text(d => d.id)
  			.attr("dy", "0.4em");
  
  // setting the positions of the links and nodes by applying the simulation defined above
 	simulation.on("tick", () => {
    // position of two ends of the link (x1,y1) and (x2,y2)
    link
 			.attr("x1", d => d.source.x)
 			.attr("y1", d => d.source.y)
 			.attr("x2", d => d.target.x)
 			.attr("y2", d => d.target.y);
    // Setting the position of nodes x and y.
    node
    	.attr("transform", d => "translate(" + d.x + ", " + d.y + ")");
  });

});
